"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.agileWorkCreate = void 0;
const constants_1 = require("../../../../../../../constants");
const extensions_1 = require("../../../../../../../extensions");
const utils_1 = require("../../../../../../../utils");
exports.agileWorkCreate = new extensions_1.Command()
    .name("create")
    .description("Work Item Creation")
    .option("-f, --file <file>", "File containing backlog item template")
    .option("-p, --params <params>", "Path to JSON file with values for all variable interpolation")
    .addAction((serviceCollection, options) => __awaiter(void 0, void 0, void 0, function* () {
    const { agileService } = serviceCollection;
    if (!agileService) {
        throw new Error("Section 'agile' must be configured for this command");
    }
    // Read agile items from provided file
    const { file, params: paramsPath } = options;
    const templatePath = file || constants_1.FileConstants.backlogItemsFileName;
    const parameters = utils_1.FileUtils.readJson(paramsPath);
    const template = utils_1.FileUtils.readJson(templatePath, parameters);
    if (!template) {
        throw new Error(`Could not find template '${templatePath}'`);
    }
    // Create Backlog Items
    const items = yield agileService.createBacklogItems(template.items);
    utils_1.Logger.logHeader("Created Items");
    items.forEach((item) => utils_1.Logger.log(`${item.id} - ${item.name}`));
}));
