"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Command = void 0;
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = require("commander");
const figlet_1 = __importDefault(require("figlet"));
const factories_1 = require("../factories");
const services_1 = require("../services");
const utils_1 = require("../utils");
const urlCommand_1 = require("./urlCommand");
class Command extends commander_1.Command {
    constructor() {
        super();
        this.actions = [];
    }
    initialize(initializeAction) {
        initializeAction();
        return this;
    }
    addAction(actionHandler) {
        this.actions.push(actionHandler);
        this.action(() => {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const options = this.opts();
            const config = services_1.ConfigService.getExistingConfig(options);
            const serviceCollection = factories_1.createServiceCollection(options);
            this.actions.forEach((action) => {
                action(serviceCollection, options, config);
            });
        });
        return this;
    }
    printHelp() {
        this.addAction(() => {
            utils_1.Logger.log(this.helpInformation());
        });
        return this;
    }
    asciiArt(message) {
        this.addAction(() => {
            utils_1.Logger.log(chalk_1.default.cyanBright(figlet_1.default.textSync(message)));
        });
        return this;
    }
    addLinkCommands(links) {
        links.forEach((link) => this.addCommand(urlCommand_1.urlCommand(link)));
        return this;
    }
    toMarkdownDoc(parentCommandPath) {
        const commandPath = `${parentCommandPath ? parentCommandPath + " " : ""}${this.name()}`;
        let doc = `## \`${commandPath}\`\n\n`;
        doc += "```\n" + this.helpInformation() + "```";
        for (const command of this.commands) {
            if (command instanceof Command) {
                doc += `\n${command.toMarkdownDoc(commandPath)}`;
            }
        }
        return doc;
    }
    toTableOfContents(parentIndentation, parentCommandPath) {
        const indentation = parentIndentation !== undefined ? parentIndentation + "  " : "";
        const commandPath = `${parentCommandPath ? parentCommandPath + " " : ""}${this.name()}`;
        const line = "- [`" + commandPath + "`]" + `(#${commandPath.replace(/ /g, "-")}) - ${this.description()}`;
        let toc = indentation + line;
        for (const command of this.commands) {
            if (command instanceof Command) {
                toc += `\n${command.toTableOfContents(indentation, commandPath)}`;
            }
        }
        return toc;
    }
}
exports.Command = Command;
